@@ -4,7 +4,7 @@
 
 ;; Maintainer: Nicolas P. Rougier <Nicolas.Rougier@inria.fr>
 ;; URL: https://github.com/rougier/nano-theme
-;; Version: 0.2
+;; Version: 0.3.0
 ;; Package-Requires: ((emacs "27.1"))
 ;; Keywords: theme, dark, light
 
@@ -94,6 +94,14 @@
 
 ;;; NEWS:
 
+;; Version 0.3.0
+;; - Added italic (Victor Mono)
+;; - Less salient critical face
+;; - Added orderles, marginalia & corfu faces
+
+;; Version 0.2.1
+;; - Added nano-modeline faces
+
 ;; Version 0.2
 ;; - Split light / dark themes properly
 ;; - Added a nano-new-frame function
@@ -109,7 +117,7 @@
   :group 'convenience)
 
 (defgroup nano-theme nil
-  "Theme"
+  "N Λ N O Theme"
   :group 'nano)
 
 (defgroup nano-theme-light nil
@@ -156,6 +164,14 @@
   "Default proportional serif font (Roboto Slab Light, 14pt)."
   :group 'nano-theme-fonts)
 
+(defface nano-italic
+  '((t (:family "Victor Mono"
+        :slant italic
+        :height 140
+        :weight regular)))
+  "Default italic font (Victor Mono Italic Light, 14pt)."
+  :group 'nano-theme-fonts)
+
 (defcustom nano-light-foreground "#37474F" ;; Blue Grey / L800
   "Default foreground color"
   :type 'color :group 'nano-theme-light)
@@ -172,7 +188,7 @@
   "Subtle color is used to suggest a physical area on the screen."
   :type 'color :group 'nano-theme-light)
 
-(defcustom nano-light-faded "#B0BEC5" ;; Blue Grey / L200
+(defcustom nano-light-faded "#90A4AE" ;; Blue Grey / L300
   "Faded face is for information that are less important."
   :type 'color :group 'nano-theme-light)
 
@@ -180,7 +196,7 @@
   "Salient color is used for information that are important."
   :type 'color :group 'nano-theme-light)
 
-(defcustom nano-light-strong "#000000" ;; Black
+(defcustom nano-light-strong "#263238" ;; Blue Grey / L900
   "Strong color is used for information of a structural nature."
   :type 'color :group 'nano-theme-light)
 
@@ -387,7 +403,7 @@ background color that is barely perceptible."
                  '(menu-bar-lines . 0))))
 
   ;; Line spacing (in pixels)
-  (setq line-spacing 0)
+  ;; (setq line-spacing 0)
   
   ;; Vertical window divider
   (setq window-divider-default-right-width 24)
@@ -460,32 +476,66 @@ background color that is barely perceptible."
   "Load the nano dark theme on current frame."
 
   (interactive)
-  (set-foreground-color nano-dark-foreground)
-  (set-background-color nano-dark-background)
+   ;; (let ((parent (selected-frame))
+   ;;        (children (frame-list)))
+   ;;    (dolist (child children)
+   ;;      (when (eq (frame-parameter child 'parent-frame) parent)
+   ;;        (with-selected-frame child
+   ;;          (setq frame-background-mode 'dark)
+   ;;          (set-foreground-color nano-dark-foreground)
+   ;;          (set-background-color nano-dark-background)
+   ;;          (frame-set-background-mode child)
+   ;;          (load-theme 'nano-dark t)))))
+  ;;  (set-foreground-color nano-dark-foreground)
+  ;;   (set-background-color nano-dark-background)
   (load-theme 'nano-dark t))
 
 (defun nano-light ()
   "Load the nano light theme on current frame."
 
   (interactive)
-  (set-foreground-color nano-light-foreground)
-  (set-background-color nano-light-background)
   (load-theme 'nano-light t))
 
+(defvar nano-theme--current 'light
+  "Current nano theme")
+
+(defun nano-theme-toggle ()
+  "Toggle theme on current frame."
+
+  (interactive)
+  (if (eq nano-theme--current 'light)
+      (nano-dark)
+    (nano-light)))
+
 
 (defun nano-theme (mode)
   "Apply the nano theme according to MODE which can be 'dark or 'light."
 
+  ;; (message (format "Theme applied: %s" mode))
+  
   (let ((light     '((background light)))
         (dark      '((background dark)))
         (theme      (if (eq mode 'dark)
                        'nano-dark
-                     'nano-light)))
+                      'nano-light)))
+    
+     (add-to-list 'default-frame-alist `(background-mode . ,mode))
+     (add-to-list 'default-frame-alist `(background-color . ,(if (eq mode 'light)
+                                                                 nano-light-background
+                                                               nano-dark-background)))
+     (add-to-list 'default-frame-alist `(foreground-color . ,(if (eq mode 'light)
+                                                                 nano-light-foreground
+                                                               nano-dark-foreground)))
 
-    (set-frame-parameter nil 'background-mode mode)
+    (custom-set-variables '(widget-image-enable nil)
+                          '(x-underline-at-descent-line t))
+    
+    ;; (set-frame-parameter nil 'background-mode mode)
     (setq frame-background-mode mode)
     (frame-set-background-mode (selected-frame))
-    
+    ;; (setq nano-theme--current mode)
+    ;; (frame-set-background-mode (selected-frame))
+
     (when nano-fonts-use
         (custom-theme-set-faces theme
          `(default ((,light (:foreground ,nano-light-foreground
@@ -496,8 +546,18 @@ background color that is barely perceptible."
                              :weight     ,(face-attribute 'nano-mono :weight)
                              :height     ,(face-attribute 'nano-mono :height)
                              :family     ,(face-attribute 'nano-mono :family)))))
-         `(nano-strong ((,light (:weight normal))
-                        (,dark  (:weight normal))))
+         `(italic ((,light (:foreground ,nano-light-foreground
+                             :weight     ,(face-attribute 'nano-italic :weight)
+                             :height     ,(face-attribute 'nano-italic :height)
+                             :slant      ,(face-attribute 'nano-italic :slant)
+                             :family     ,(face-attribute 'nano-italic :family)))
+                    (,dark  (:foreground ,nano-dark-foreground
+                             :weight     ,(face-attribute 'nano-italic :weight)
+                             :height     ,(face-attribute 'nano-italic :height)
+                             :slant      ,(face-attribute 'nano-italic :slant)
+                             :family     ,(face-attribute 'nano-italic :family)))))
+         `(nano-strong ((,light (:weight normal ))
+                        (,dark  (:weight normal ))))
          `(variable-pitch  ((t (:weight ,(face-attribute 'nano-sans :weight)
                                 :height ,(face-attribute 'nano-sans :height)
                                 :family ,(face-attribute 'nano-sans :family)))))))
@@ -506,13 +566,19 @@ background color that is barely perceptible."
         (custom-theme-set-faces theme
          `(default ((,light (:foreground ,nano-light-foreground))
                     (,dark  (:foreground ,nano-dark-foreground))))
-         `(nano-strong ((,light (:weight bold))
-                        (,dark  (:weight bold))))))
+         `(nano-strong ((,light (:weight bold :foreground ,nano-light-strong))
+                        (,dark  (:weight bold :foreground ,nano-dark-strong))))))
 
-  
-  (custom-theme-set-faces theme
+    
+    (custom-theme-set-faces theme
    
    ;; --- Base ---------------------------------------------------------   
+
+;;   `(default ((,light  (:background ,nano-light-background
+;;                        :foreground ,nano-light-foreground))
+;;              (,dark  (:background ,nano-dark-background
+;;                       :foreground ,nano-dark-foreground))))
+
    `(cursor ((,light (:foreground ,nano-light-background
                       :background ,nano-light-foreground))
              (,dark  (:foreground ,nano-dark-background
@@ -574,17 +640,17 @@ background color that is barely perceptible."
                     (,dark  (:foreground ,nano-dark-background
                              :background ,nano-dark-popout))))
    
-   `(nano-critical ((,light (:foreground ,nano-light-background
-                             :background ,nano-light-critical))
-                    (,dark  (:foreground ,nano-dark-background
-                             :background ,nano-dark-critical))))
+   `(nano-critical ((,light (:foreground ,nano-light-critical
+                             :weight normal))
+                    (,dark  (:foreground ,nano-dark-critical
+                             :weight normal))))
 
-   `(nano-critical-i ((,light (:foreground ,nano-light-critical
-                            ;; :background ,nano-light-background
-                                           ))
-                      (,dark  (:foreground ,nano-dark-critical
-                   ;; :background ,nano-dark-background
-                    ))))
+   `(nano-critical-i ((,light (:foreground ,nano-light-background
+                               :background ,nano-light-critical
+                               :weight normal))
+                      (,dark  (:foreground ,nano-dark-background
+                               :background ,nano-dark-critical
+                               :weight normal))))
    
    ;; --- Header & mode line -------------------------------------------
    
@@ -653,8 +719,8 @@ background color that is barely perceptible."
    '(trailing-whitespace           ((t (:inherit nano-subtle))))
    '(secondary-selection           ((t (:inherit nano-subtle))))
    '(completions-annotations       ((t (:inherit nano-faded))))
-   '(completions-common-part       ((t (:inherit nano-faded))))
-   '(completions-first-difference  ((t (:inherit default))))
+   '(completions-common-part       ((t (:inherit nano-strong))))
+   '(completions-first-difference  ((t (:inherit nano-default))))
    '(tooltip                       ((t (:inherit nano-subtle))))
    '(read-multiple-choice-face     ((t (:inherit nano-strong))))
    '(nobreak-hyphen                ((t (:inherit nano-popout))))
@@ -691,7 +757,7 @@ background color that is barely perceptible."
    ;; --- Font lock ----------------------------------------------------
    '(font-lock-comment-face        ((t (:inherit nano-faded))))
    '(font-lock-doc-face            ((t (:inherit nano-faded))))
-   '(font-lock-string-face         ((t (:inherit nano-popout))))
+   '(font-lock-string-face         ((t (:inherit nano-faded))))
    '(font-lock-constant-face       ((t (:inherit nano-salient))))
    '(font-lock-warning-face        ((t (:inherit nano-popout))))
    '(font-lock-function-name-face  ((t (:inherit nano-strong))))
@@ -727,6 +793,9 @@ background color that is barely perceptible."
     '(company-scrollbar-fg                 ((t (:inherit nano-default-i))))
     '(company-scrollbar-bg                 ((t (:inherit nano-faded-i))))
 
+    '(company-tooltip-scrollbar-thumb      ((t (:inherit nano-default-i))))
+    '(company-tooltip-scrollbar-track      ((t (:inherit nano-faded-i))))
+    
     '(company-tooltip-common               ((t (:inherit nano-strong))))
     '(company-tooltip-common-selection     ((t (:inherit nano-salient-i
                                                 :weight normal))))
@@ -789,6 +858,39 @@ background color that is barely perceptible."
    ;; --- Helpful ------------------------------------------------------
    '(helpful-heading                ((t (:inherit nano-strong))))
 
+   ;; --- Nano modeline ------------------------------------------------
+   '(nano-modeline-active               ((t (:inherit nano-subtle))))
+   '(nano-modeline-active-name          ((t (:inherit (nano-strong nano-modeline-active)))))
+   '(nano-modeline-active-primary       ((t (:inherit (nano-default nano-modeline-active)))))
+   '(nano-modeline-active-secondary     ((t (:inherit (nano-faded nano-modeline-active)))))
+   '(nano-modeline-active-status-RO     ((t (:inherit (nano-subtle nano-strong)))))
+   '(nano-modeline-active-status-RW     ((t (:inherit (nano-faded-i nano-strong)))))
+   '(nano-modeline-active-status-**     ((t (:inherit (nano-popout-i nano-strong)))))
+
+   '(nano-modeline-inactive             ((t (:inherit nano-subtle))))
+   '(nano-modeline-inactive-name        ((t (:inherit (nano-faded nano-modeline-inactive)))))
+   '(nano-modeline-inactive-primary     ((t (:inherit (nano-faded nano-modeline-inactive)))))
+   '(nano-modeline-inactive-secondary   ((t (:inherit (nano-faded nano-modeline-inactive)))))
+   '(nano-modeline-inactive-status-RO   ((t (:inherit (nano-faded
+                                                       nano-strong nano-modeline-inactive)))))
+   '(nano-modeline-inactive-status-RW   ((t (:inherit (nano-faded
+                                                       nano-strong nano-modeline-inactive)))))
+   '(nano-modeline-inactive-status-**   ((t (:inherit (nano-popout
+                                                       nano-strong nano-modeline-inactive)))))
+
+   ;; --- nano agenda ---------------------------------------------------------
+   '(nano-agenda-button               ((t (:inherit (nano-faded)))))
+   '(nano-agenda-day-name             ((t (:inherit (nano-faded)))))
+   '(nano-agenda-default              ((t (:inherit (nano-default)))))
+   '(nano-agenda-holidays             ((t (:inherit (nano-faded)))))
+   '(nano-agenda-month-name           ((t (:inherit (nano-strong)))))
+   '(nano-agenda-mouse                ((t (:inherit (nano-highlight)))))
+   '(nano-agenda-outday               ((t (:inherit (nano-subtle-i)))))
+   '(nano-agenda-selected             ((t (:inherit (nano-default-i)))))
+   '(nano-agenda-selected-today       ((t (:inherit (nano-popout-i nano-strong)))))
+   '(nano-agenda-today                ((t (:inherit (nano-popout nano-strong)))))
+   '(nano-agenda-weekend              ((t (:inherit (nano-faded)))))
+
    ;; --- EPA ----------------------------------------------------------
    '(epa-field-body                 ((t (:inherit nano-default))))
    '(epa-field-name                 ((t (:inherit nano-strong))))
@@ -823,6 +925,22 @@ background color that is barely perceptible."
    '(diff-refine-changed            ((t (:inherit nano-popout))))
    '(diff-refine-removed            ((t (:inherit nano-faded
                                          :strike-through t))))
+
+   ;; --- Corfu --------------------------------------------------------
+   '(corfu-annotations              ((t (:inherit nano-faded))))
+   '(corfu-bar                      ((t (:inherit nano-default-i))))
+   '(corfu-border                   ((t (:inherit nano-default-i))))
+   '(corfu-current                  ((t (:inherit highlight))))
+   '(corfu-default                  ((t (:inherit nano-subtle))))
+   '(corfu-deprecated               ((t (:inherit nano-faded))))
+   '(corfu-echo                     ((t (:inherit nano-faded))))
+
+   ;; --- Orderless ----------------------------------------------------
+   '(orderless-match-face-0         ((t (:inherit (nano-salient
+                                                   nano-strong)))))
+   '(orderless-match-face-1         ((t (:inherit (nano-strong)))))
+   '(orderless-match-face-2         ((t (:inherit (nano-strong)))))
+   '(orderless-match-face-3         ((t (:inherit (nano-strong)))))
    
    ;; --- Message ------------------------------------------------------
    '(message-cited-text-1           ((t (:inherit nano-faded))))
@@ -851,8 +969,10 @@ background color that is barely perceptible."
    '(outline-8                      ((t (:inherit nano-strong))))
    
    ;; --- Fly spell ----------------------------------------------------
-   '(flyspell-duplicate             ((t (:inherit nano-popout))))
-   '(flyspell-incorrect             ((t (:inherit nano-popout))))
+   '(flyspell-duplicate             ((t (:inherit (highlight nano-faded)
+                                         :underline t))))
+   '(flyspell-incorrect             ((t (:inherit (highlight nano-faded)
+                                         :underline t))))
 
    ;; --- Org agenda ---------------------------------------------------
    '(org-agenda-calendar-event      ((t (:inherit nano-default))))
@@ -884,7 +1004,7 @@ background color that is barely perceptible."
    '(org-checkbox-statistics-done            ((t (:inherit nano-faded))))
    '(org-checkbox-statistics-todo            ((t (:inherit nano-faded))))
    '(org-clock-overlay                       ((t (:inherit nano-faded))))
-   '(org-code                                ((t (:inherit nano-faded))))
+   '(org-code                                ((t (:inherit nano-default))))
    '(org-column                              ((t (:inherit nano-faded))))
    '(org-column-title                        ((t (:inherit nano-faded))))
    '(org-date                                ((t (:inherit nano-faded))))
@@ -1045,7 +1165,41 @@ background color that is barely perceptible."
    '(gnus-summary-normal-undownloaded       ((t (:inherit nano-faded))))
    '(gnus-summary-normal-unread             ((t (:inherit nano-faded))))
    '(gnus-summary-selected                  ((t (:inherit nano-faded))))
-   
+
+   ;; --- Marginalia ---------------------------------------------------
+   '(marginalia-archive                     ((t (:inherit nano-faded))))
+   '(marginalia-char                        ((t (:inherit nano-faded))))
+   '(marginalia-date                        ((t (:inherit nano-faded))))
+   '(marginalia-documentation               ((t (:inherit nano-faded))))
+   '(marginalia-file-name                   ((t (:inherit nano-faded))))
+   '(marginalia-file-owner                  ((t (:inherit nano-faded))))
+   '(marginalia-file-priv-dir               ((t (:inherit nano-faded))))
+   '(marginalia-file-priv-exec              ((t (:inherit nano-faded))))
+   '(marginalia-file-priv-link              ((t (:inherit nano-faded))))
+   '(marginalia-file-priv-no                ((t (:inherit nano-faded))))
+   '(marginalia-file-priv-other             ((t (:inherit nano-faded))))
+   '(marginalia-file-priv-rare              ((t (:inherit nano-faded))))
+   '(marginalia-file-priv-read              ((t (:inherit nano-faded))))
+   '(marginalia-file-priv-write             ((t (:inherit nano-faded))))
+   '(marginalia-function                    ((t (:inherit nano-faded))))
+   '(marginalia-installed                   ((t (:inherit nano-faded))))
+   '(marginalia-key                         ((t (:inherit nano-faded))))
+   '(marginalia-lighter                     ((t (:inherit nano-faded))))
+   '(marginalia-list                        ((t (:inherit nano-faded))))
+   '(marginalia-mode                        ((t (:inherit nano-faded))))
+   '(marginalia-modified                    ((t (:inherit nano-faded))))
+   '(marginalia-null                        ((t (:inherit nano-faded))))
+   '(marginalia-number                      ((t (:inherit nano-faded))))
+   '(marginalia-off                         ((t (:inherit nano-faded))))
+   '(marginalia-on                          ((t (:inherit nano-faded))))
+   '(marginalia-size                        ((t (:inherit nano-faded))))
+   '(marginalia-string                      ((t (:inherit nano-faded))))
+   '(marginalia-symbol                      ((t (:inherit nano-faded))))
+   '(marginalia-true                        ((t (:inherit nano-faded))))
+   '(marginalia-type                        ((t (:inherit nano-faded))))
+   '(marginalia-value                       ((t (:inherit nano-faded))))
+   '(marginalia-version                     ((t (:inherit nano-faded))))
+
    ;; --- Elfeed -------------------------------------------------------
     '(elfeed-log-date-face                    ((t (:inherit nano-faded))))
     '(elfeed-log-info-level-face            ((t (:inherit nano-default))))
@@ -1090,6 +1244,8 @@ background color that is barely perceptible."
     '(rst-reference                         ((t (:inherit nano-salient))))
     '(rst-transition                        ((t (:inherit nano-default))))
 
+
+    
     ;; --- Markdown ----------------------------------------------------
     '(markdown-blockquote-face              ((t (:inherit nano-default))))
     '(markdown-bold-face                     ((t (:inherit nano-strong))))
@@ -1134,6 +1290,119 @@ background color that is barely perceptible."
     '(markdown-table-face                   ((t (:inherit nano-default))))
     '(markdown-url-face                     ((t (:inherit nano-salient))))
 
+    ;; --- Magit (WIP) ---------------------------------------------------
+    '(magit-blame-highlight                  ((t (:inherit (highlight)))))
+    '(magit-diff-added-highlight             ((t (:inherit (highlight nano-salient nano-strong)))))
+    '(magit-diff-base-highlight              ((t (:inherit (highlight)))))
+    '(magit-diff-context-highlight           ((t (:inherit (highlight nano-faded)))))
+    '(magit-diff-file-heading-highlight      ((t (:inherit (highlight nano-strong)))))
+    '(magit-diff-hunk-heading-highlight      ((t (:inherit (nano-default)))))
+    '(magit-diff-our-highlight               ((t (:inherit (highlight)))))
+    '(magit-diff-removed-highlight           ((t (:inherit (highlight nano-popout nano-strong)))))
+    '(magit-diff-revision-summary-highlight  ((t (:inherit ()))))
+    '(magit-diff-their-highlight             ((t (:inherit (highlight)))))
+    '(magit-section-highlight                ((t (:inherit (highlight)))))
+
+    '(magit-blame-heading                    ((t (:inherit (nano-subtle nano-strong)))))
+    '(magit-diff-conflict-heading            ((t (:inherit (nano-subtle nano-strong)))))
+    '(magit-diff-file-heading                ((t (:inherit (nano-strong)))))
+    '(magit-diff-hunk-heading                ((t (:inherit (nano-subtle nano-default)))))
+    '(magit-diff-lines-heading               ((t (:inherit (nano-subtle nano-strong)))))
+    '(magit-section-heading                  ((t (:inherit (nano-salient nano-strong)))))
+
+    '(magit-bisect-bad                       ((t (:inherit nano-default))))
+    '(magit-bisect-good                      ((t (:inherit nano-default))))
+    '(magit-bisect-skip                      ((t (:inherit nano-default))))
+    '(magit-blame-date                       ((t (:inherit nano-default))))
+    '(magit-blame-dimmed                     ((t (:inherit nano-default))))
+    '(magit-blame-hash                       ((t (:inherit nano-faded))))
+
+    '(magit-blame-margin                     ((t (:inherit nano-default))))
+    '(magit-blame-name                       ((t (:inherit nano-default))))
+    '(magit-blame-summary                    ((t (:inherit nano-default))))
+
+    '(magit-branch-current                   ((t (:inherit (nano-strong nano-salient)))))
+    '(magit-branch-local                     ((t (:inherit nano-salient))))
+    '(magit-branch-remote                    ((t (:inherit (nano-salient)))))
+    '(magit-branch-remote-head               ((t (:inherit (nano-salient)))))
+    '(magit-branch-upstream                  ((t (:inherit (nano-salient)))))
+
+    '(magit-cherry-equivalent                ((t (:inherit nano-default))))
+    '(magit-cherry-unmatched                 ((t (:inherit nano-default))))
+
+    '(magit-diff-added                       ((t (:inherit (highlight nano-salient nano-strong)))))
+    '(magit-diff-base                        ((t (:inherit nano-default))))
+    '(magit-diff-context                     ((t (:inherit (highlight nano-faded)))))
+    '(magit-diff-file-heading-selection      ((t (:inherit nano-default))))
+    '(magit-diff-hunk-heading-selection      ((t (:inherit nano-default))))
+    '(magit-diff-hunk-region                 ((t (:inherit nano-default))))
+    '(magit-diff-lines-boundary              ((t (:inherit nano-default))))
+    '(magit-diff-our                         ((t (:inherit nano-default))))
+    '(magit-diff-removed                     ((t (:inherit (highlight nano-popout nano-strong)))))
+    '(magit-diff-revision-summary            ((t (:inherit nano-popout))))
+    '(magit-diff-their                       ((t (:inherit nano-default))))
+    '(magit-diff-whitespace-warning          ((t (:inherit nano-default))))
+    '(magit-diffstat-added                   ((t (:inherit nano-default))))
+    '(magit-diffstat-removed                 ((t (:inherit nano-default))))
+
+    '(magit-dimmed                           ((t (:inherit nano-faded))))
+    '(magit-filename                         ((t (:inherit nano-default))))
+    '(magit-hash                             ((t (:inherit nano-faded))))
+    '(magit-head                             ((t (:inherit nano-default))))
+    '(magit-header-line                      ((t (:inherit nano-default))))
+    '(magit-header-line-key                  ((t (:inherit nano-default))))
+    '(magit-header-line-log-select           ((t (:inherit nano-default))))
+
+    '(magit-keyword                          ((t (:inherit nano-default))))
+    '(magit-keyword-squash                   ((t (:inherit nano-default))))
+
+    '(magit-log-author                       ((t (:inherit nano-default))))
+    '(magit-log-date                         ((t (:inherit nano-default))))
+    '(magit-log-graph                        ((t (:inherit nano-default))))
+
+    '(magit-mode-line-process                ((t (:inherit nano-default))))
+    '(magit-mode-line-process-error          ((t (:inherit nano-default))))
+
+    '(magit-process-ng                       ((t (:inherit nano-default))))
+    '(magit-process-ok                       ((t (:inherit nano-default))))
+
+    '(magit-reflog-amend                     ((t (:inherit nano-default))))
+    '(magit-reflog-checkout                  ((t (:inherit nano-default))))
+    '(magit-reflog-cherry-pick               ((t (:inherit nano-default))))
+    '(magit-reflog-commit                    ((t (:inherit nano-default))))
+    '(magit-reflog-merge                     ((t (:inherit nano-default))))
+    '(magit-reflog-other                     ((t (:inherit nano-default))))
+    '(magit-reflog-rebase                    ((t (:inherit nano-default))))
+    '(magit-reflog-remote                    ((t (:inherit nano-default))))
+    '(magit-reflog-reset                     ((t (:inherit nano-default))))
+    '(magit-refname                          ((t (:inherit nano-default))))
+    '(magit-refname-pullreq                  ((t (:inherit nano-default))))
+    '(magit-refname-stash                    ((t (:inherit nano-default))))
+    '(magit-refname-wip                      ((t (:inherit nano-default))))
+
+    '(magit-section-heading-selection        ((t (:inherit nano-default))))
+    '(magit-section-secondary-heading        ((t (:inherit nano-default))))
+    '(magit-sequence-done                    ((t (:inherit nano-default))))
+    '(magit-sequence-drop                    ((t (:inherit nano-default))))
+    '(magit-sequence-exec                    ((t (:inherit nano-default))))
+    '(magit-sequence-head                    ((t (:inherit nano-default))))
+    '(magit-sequence-onto                    ((t (:inherit nano-default))))
+    '(magit-sequence-part                    ((t (:inherit nano-default))))
+    '(magit-sequence-pick                    ((t (:inherit nano-default))))
+    '(magit-sequence-stop                    ((t (:inherit nano-default))))
+
+    '(magit-signature-bad                    ((t (:inherit nano-default))))
+    '(magit-signature-error                  ((t (:inherit nano-default))))
+    '(magit-signature-expired                ((t (:inherit nano-default))))
+    '(magit-signature-expired-key            ((t (:inherit nano-default))))
+    '(magit-signature-good                   ((t (:inherit nano-default))))
+    '(magit-signature-revoked                ((t (:inherit nano-default))))
+    '(magit-signature-untrusted              ((t (:inherit nano-default))))
+
+    '(magit-tag                              ((t (:inherit nano-default-i))))
+
+
+    
     ;; --- Terminal ----------------------------------------------------
     '(term-bold        ((t (:inherit nano-strong))))
     '(term-color-black ((t (:inherit default))))
